.. _use_ref:

Reference
=========

Shape Reference
---------------

Here you can find detailed information on all the shapes that come built into 
:code:`stylo`

.. Eventually we will want to use this directive - but the css needs some tweaking
.. in topos-theme to make it look nice.
.. hlist: :

- :ref:`use_ref_shape_circle`
- :ref:`use_ref_shape_ellipse`
- :ref:`use_ref_shape_implicit_xy`
- :ref:`use_ref_shape_line`

Index
-----

.. toctree::
   :maxdepth: 1

   circle
   ellipse
   implicit_xy
   line
